from Testing import ZopeTestCase as ztc
from ftw.globalstatusmessage.tests.base import GSMTestCase
import doctest
import unittest


MODULENAMES = ()


TESTFILES = (
    'globalstatusmessage.txt',
    )


OPTIONFLAGS = (doctest.NORMALIZE_WHITESPACE |
               doctest.ELLIPSIS |
               doctest.REPORT_NDIFF)


# def test_suite():
# 
#     suite = unittest.TestSuite()
# 
#     for testfile in TESTFILES:
#         fdfs = ZopeTestCase.FunctionalDocFileSuite(
#             'globalstatusmessage.txt',
#             optionflags=OPTIONFLAGS,
#             test_class=ptc.FunctionalTestCase,)
#         fdfs.layer = layer.gsm_integration_layer
#         suite.addTest(fdfs)
#         
#     return suite
# 
# if __name__ == '__main__':
#     unittest.main(defaultTest='test_suite')
def test_suite():
    return unittest.TestSuite([
        # doctests in file bar.txt
        ztc.ZopeDocFileSuite(
            'globalstatusmessage.txt', package='ftw.globalstatusmessage.tests',
            test_class=GSMTestCase, optionflags=OPTIONFLAGS),

        # docstring tests for module ftw.foo.bar
             ztc.ZopeDocTestSuite(
                         'ftw.globalstatusmessage.config',
                          test_class=GSMTestCase, optionflags=OPTIONFLAGS),
                 ])

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')


from zope.interface import Interface
from zope import schema
from ftw.globalstatusmessage import _
from plone.theme.interfaces import IDefaultPloneLayer


class IStatusMessageConfigForm(Interface):
    """This interface defines the configlet."""
    enabled_bool = schema.Bool(
    title = _(u"statusmessage_label_Active", default=u"Active"),
    required = False)
    type_choice = schema.Choice(
    title = _(u"statusmessage_label_type", default=u"Type"),
    values = [_(u"information"),
    _(u"warning"),
    _(u"error")],
    required = False)
    title_textfield = schema.TextLine(
    title = _(u"statusmessage_label_title", default= u"Title"),
    required = False)
    message_textfield = schema.Text(
    title = _(u"statusmessage_label_message", default= u"Message"),
    required = False)


class IGlobalStatusMessageLayer(IDefaultPloneLayer):
    """Marker interface that defines a Zope 3 browser layer.
    """



from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
from plone.app.layout.viewlets import common


class StatusmessageViewlet(common.PathBarViewlet):
    render = ViewPageTemplateFile('statusmessage.pt')



from collective.testcaselayer.ptc import BasePTCLayer, ptc_layer
# from ftw.globalstatusmessage import tests

class GSMIntegrationLayer(BasePTCLayer):
    """Layer for integration tests."""

    def afterSetUp(self):

        # Load testing zcml (optional)
        # self.loadZCML('testing.zcml', package=tests)

        # installPackage() is *only* necessary for packages outside
        # the Products.* namespace which are also declared as Zope 2 products,
        # using <five:registerPackage /> in ZCML.
        # installPackage('ftw.globalstatusmessage')

        # # Load GS profile
        # import pdb; pdb.set_trace( )
        self.addProfile('ftw.globalstatusmessage:default')

    def beforeTearDown(self):
        pass

gsm_integration_layer = GSMIntegrationLayer(bases=[ptc_layer])



from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from ftw.globalstatusmessage.config import FormAdapter


def setup_site(portal):
    control
    sm = portal.getSite()
    sitemanager = sm.getSiteManager()
    test = sitemanager.queryUtility(IStatusMessageConfigForm,
        name='Global_Statusmessage')
    if not test:
        sitemanager.registerUtility(FormAdapter,
            IStatusMessageConfigForm, 'Global_Statusmessage')


def control(context):
    if context.readDataFile('ftw.globalstatusmessage_various.txt') is None:
        return



from zope.interface import implements
from ftw.globalstatusmessage.interfaces import IStatusMessageConfigForm
from Products.CMFDefault.formlib.schema import SchemaAdapterBase
from Products.CMFCore.utils import getToolByName
from zope.component import adapts
from Products.CMFPlone.Portal import PloneSite


class FormAdapter(SchemaAdapterBase):
    """this class adapts the plonesite for the Interface"""
    implements(IStatusMessageConfigForm)
    adapts(PloneSite)

    def __init__(self, context):
        super(FormAdapter, self).__init__(context)
        pprop = getToolByName(context, 'portal_properties')
        self.statusProps = pprop.ftw_globalstatusmessage_properties

    def get_active(self):
        return self.statusProps.getProperty('Active')

    def set_active(self, value):
        self.statusProps._updateProperty('Active', value)

    enabled_bool = property(get_active, set_active)

    def get_type(self):
        return self.statusProps.getProperty('Type')

    def set_type(self, value):
        self.statusProps._updateProperty('Type', value)
    type_choice = property(get_type, set_type)

    def get_title(self):
        return self.statusProps.getProperty('Title')

    def set_title(self, value):
        self.statusProps._updateProperty('Title', value)

    title_textfield = property(get_title, set_title)

    def get_message(self):
        return self.statusProps.getProperty('Message').decode('utf-8')

    def set_message(self, value):

        if not value:
            value = ""

        self.statusProps._updateProperty('Message', value.encode('utf-8'))
    message_textfield = property(get_message, set_message)



from setuptools import setup, find_packages
import os


tests_require = [
      'collective.testcaselayer',
      'Plone']


def read(*rnames):
    return open('/'.join(rnames)).read()

version = '1.1'
maintainer = 'Mathias Leimgruber'


setup(name='ftw.globalstatusmessage',
      version=version,
      description="Shows a global message on every site.",
      long_description=open("README.rst").read() + "\n" +
                       open(os.path.join("docs", "HISTORY.txt")).read(),
      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        ],
      keywords='',
      author='4teamwork GmbH',
      author_email='info@4teamwork.ch',
      url='http://psc.4teamwork.ch/4teamwork/ftw/ftw-globalstatusmessage',
      license='GPL2',
      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['ftw'],
      include_package_data=True,
      zip_safe=False,
      install_requires=[
          'setuptools',
          'z3c.autoinclude'
          # -*- Extra requirements: -*-
      ],
      tests_require=tests_require,
      extras_require=dict(tests=tests_require),
      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )



from Products.PloneTestCase import ptc
from ftw.globalstatusmessage.tests.layer import gsm_integration_layer


class GSMTestCase(ptc.PloneTestCase):
    """Base class for integration tests."""

    layer = gsm_integration_layer
